@@ -60,7 +60,7 @@ data GithubOwner = GithubUser {
   ,githubOwnerLogin :: String
   ,githubOwnerUrl :: String
   ,githubOwnerId :: Int
-  ,githubOwnerGravatarId :: String
+  ,githubOwnerGravatarId :: Maybe String
   }
   | GithubOrganization {
    githubOwnerAvatarUrl :: String
@@ -107,6 +107,14 @@ data Comment = Comment {
   ,commentId :: Int
 } deriving (Show, Data, Typeable, Eq, Ord)
 
+data NewComment = NewComment {
+   newCommentBody :: String
+} deriving (Show, Data, Typeable, Eq, Ord)
+
+data EditComment = EditComment {
+   editCommentBody :: String
+} deriving (Show, Data, Typeable, Eq, Ord)
+
 data Diff = Diff {
    diffStatus :: String
   ,diffBehindBy :: Int
@@ -195,6 +203,24 @@ data Issue = Issue {
   ,issueMilestone :: Maybe Milestone
 } deriving (Show, Data, Typeable, Eq, Ord)
 
+data NewIssue = NewIssue {
+  newIssueTitle :: String
+, newIssueBody :: Maybe String
+, newIssueAssignee :: Maybe String
+, newIssueMilestone :: Maybe Int
+, newIssueLabels :: Maybe [String]
+} deriving (Show, Data, Typeable, Eq, Ord)
+
+data EditIssue = EditIssue {
+  editIssueTitle :: Maybe String
+, editIssueBody :: Maybe String
+, editIssueAssignee :: Maybe String
+, editIssueState :: Maybe String
+, editIssueMilestone :: Maybe Int
+, editIssueLabels :: Maybe [String]
+} deriving  (Show, Data, Typeable, Eq, Ord)
+
+
 data Milestone = Milestone {
    milestoneCreator :: GithubOwner
   ,milestoneDueOn :: Maybe GithubDate
@@ -338,6 +364,11 @@ data PullRequestLinks = PullRequestLinks {
 data PullRequestCommit = PullRequestCommit {
 } deriving (Show, Data, Typeable, Eq, Ord)
 
+data SearchReposResult = SearchReposResult {
+  searchReposTotalCount :: Int
+  ,searchReposRepos :: [ Repo ]
+} deriving (Show, Data, Typeable, Eq, Ord)
+
 data Repo = Repo {
    repoSshUrl :: String
   ,repoDescription :: Maybe String
@@ -364,8 +395,13 @@ data Repo = Repo {
   ,repoHasWiki :: Maybe Bool
   ,repoHasIssues :: Maybe Bool
   ,repoHasDownloads :: Maybe Bool
+  ,repoParent :: Maybe RepoRef
+  ,repoSource :: Maybe RepoRef
 } deriving (Show, Data, Typeable, Eq, Ord)
 
+data RepoRef = RepoRef GithubOwner String -- Repo owner and name
+ deriving (Show, Data, Typeable, Eq, Ord)
+
 data Contributor
   -- | An existing Github user, with their number of contributions, avatar
   -- URL, login, URL, ID, and Gravatar ID.
@@ -408,7 +444,7 @@ data DetailedOwner = DetailedUser {
   ,detailedOwnerFollowers :: Int
   ,detailedOwnerFollowing :: Int
   ,detailedOwnerHireable :: Bool
-  ,detailedOwnerGravatarId :: String
+  ,detailedOwnerGravatarId :: Maybe String
   ,detailedOwnerBlog :: Maybe String
   ,detailedOwnerBio :: Maybe String
   ,detailedOwnerPublicRepos :: Int
