@@ -1,3 +1,4 @@
+{-# LANGUAGE OverloadedStrings #-}
 -- | The issues API as described on <http://developer.github.com/v3/issues/>.
 module Github.Issues (
  issue
@@ -5,6 +6,16 @@ module Github.Issues (
 ,issuesForRepo
 ,issuesForRepo'
 ,IssueLimitation(..)
+
+-- * Modifying Issues
+-- |
+-- Only authenticated users may create and edit issues.
+,GithubAuth(..)
+
+,createIssue
+,newIssue
+,editIssue
+,editOfIssue
 ,module Github.Data
 ) where
 
@@ -39,8 +50,8 @@ data IssueLimitation =
 --
 -- > issue' (Just ("github-username", "github-password")) "thoughtbot" "paperclip" "462"
 issue' :: Maybe GithubAuth -> String -> String -> Int -> IO (Either Error Issue)
-issue' auth user repoName issueNumber =
-  githubGet' auth ["repos", user, repoName, "issues", show issueNumber]
+issue' auth user reqRepoName reqIssueNumber =
+  githubGet' auth ["repos", user, reqRepoName, "issues", show reqIssueNumber]
 
 -- | Details on a specific issue, given the repo owner and name, and the issue
 -- number.
@@ -54,10 +65,10 @@ issue = issue' Nothing
 --
 -- > issuesForRepo' (Just ("github-username", "github-password")) "thoughtbot" "paperclip" [NoMilestone, OnlyClosed, Mentions "jyurek", Ascending]
 issuesForRepo' :: Maybe GithubAuth -> String -> String -> [IssueLimitation] -> IO (Either Error [Issue])
-issuesForRepo' auth user repoName issueLimitations =
+issuesForRepo' auth user reqRepoName issueLimitations =
   githubGetWithQueryString' 
     auth
-    ["repos", user, repoName, "issues"]
+    ["repos", user, reqRepoName, "issues"]
     (queryStringFromLimitations issueLimitations)
   where
     queryStringFromLimitations = intercalate "&" . map convert
@@ -84,3 +95,36 @@ issuesForRepo' auth user repoName issueLimitations =
 -- > issuesForRepo "thoughtbot" "paperclip" [NoMilestone, OnlyClosed, Mentions "jyurek", Ascending]
 issuesForRepo :: String -> String -> [IssueLimitation] -> IO (Either Error [Issue])
 issuesForRepo = issuesForRepo' Nothing
+
+
+-- Creating new issues.
+
+newIssue :: String -> NewIssue
+newIssue title = NewIssue title Nothing Nothing Nothing Nothing
+
+
+-- |
+-- Create a new issue.
+--
+-- > createIssue (GithubUser (user, password)) user repo
+-- >  (newIssue "some_repo") {...}
+createIssue :: GithubAuth -> String -> String -> NewIssue
+            -> IO (Either Error Issue)
+createIssue auth user repo = githubPost auth ["repos", user, repo, "issues"]
+
+
+-- Editing issues.
+
+editOfIssue :: EditIssue
+editOfIssue = EditIssue Nothing Nothing Nothing Nothing Nothing Nothing
+
+
+-- |
+-- Edit an issue.
+--
+-- > editIssue (GithubUser (user, password)) user repo issue
+-- >  editOfIssue {...}
+editIssue :: GithubAuth -> String -> String -> Int -> EditIssue
+            -> IO (Either Error Issue)
+editIssue auth user repo iss =
+  githubPatch auth ["repos", user, repo, "issues", show iss]
