@@ -14,19 +14,19 @@ import Github.Private
 --
 -- > eventsForIssue "thoughtbot" "paperclip" 49
 eventsForIssue :: String -> String -> Int -> IO (Either Error [Event])
-eventsForIssue user repoName issueNumber =
-  githubGet ["repos", user, repoName, "issues", show issueNumber, "events"]
+eventsForIssue user reqRepoName reqIssueNumber =
+  githubGet ["repos", user, reqRepoName, "issues", show reqIssueNumber, "events"]
 
 -- | All the events for all issues in a repo.
 --
 -- > eventsForRepo "thoughtbot" "paperclip"
 eventsForRepo :: String -> String -> IO (Either Error [Event])
-eventsForRepo user repoName =
-  githubGet ["repos", user, repoName, "issues", "events"]
+eventsForRepo user reqRepoName =
+  githubGet ["repos", user, reqRepoName, "issues", "events"]
 
 -- | Details on a specific event, by the event's ID.
 --
 -- > event "thoughtbot" "paperclip" 5335772
 event :: String -> String -> Int -> IO (Either Error Event)
-event user repoName eventId =
-  githubGet ["repos", user, repoName, "issues", "events", show eventId]
+event user reqRepoName reqEventId =
+  githubGet ["repos", user, reqRepoName, "issues", "events", show reqEventId]
