@@ -2,6 +2,7 @@ module ListWatched where
 
 import qualified Github.Repos.Watching as Github
 import Data.List (intercalate)
+import Data.Maybe (fromMaybe)
 
 main = do
   possibleRepos <- Github.reposWatchedBy "mike-burns"
@@ -11,7 +12,7 @@ main = do
 
 formatRepo repo =
   (Github.repoName repo) ++ "\t" ++
-    (Github.repoDescription repo) ++ "\n" ++
+    (fromMaybe "" $ Github.repoDescription repo) ++ "\n" ++
     (Github.repoHtmlUrl repo) ++ "\n" ++
     (Github.repoCloneUrl repo) ++ "\t" ++
     (formatDate $ Github.repoUpdatedAt repo) ++ "\n" ++
